import { Component, OnInit } from '@angular/core';
import PhylocanvasGL, { TreeTypes } from "@phylocanvas/phylocanvas.gl";
import { Router } from '@angular/router';
import { DataService } from 'src/app/services/data.service';
import { SpeciesAnalysis } from 'src/app/models/SpeciesAnalysis';
import { SearchService } from 'src/app/services/search.service';
import { reduce } from 'rxjs';
import {MatDialog, MatDialogRef, MAT_DIALOG_DATA} from '@angular/material/dialog';
import { DialogComponent } from '../dialog/dialog.component';
@Component({
  selector: 'slf-home',
  templateUrl: './home.component.html',
  styleUrls: ['./home.component.scss']
})
export class HomeComponent implements OnInit {

  species_analysis_map = new Map<string,Map<string,SpeciesAnalysis>>(); //Todos los datos leidos
  search_service: SearchService; //Funciones de búsqueda

  constructor(private dataService: DataService,
    private router: Router,
    public searchService: SearchService,public dialog: MatDialog) {

    this.species_analysis_map = dataService.species_analysis_map
    this.search_service=searchService
  }

  //Renderiza el árbol a partir del texto en formato correcto
  // Más info: https://www.phylocanvas.gl/
  tree: PhylocanvasGL;
  renderizeFilogeneticTree(): void {
    var screenSize = document.querySelector("#demo")!.getBoundingClientRect()
    screenSize.width = screenSize.width * 0.95
    screenSize.height = screenSize.height * 3
    var metadata="id,colour\nRosaceae,red\nUlmaceae,red" //Esto serian diferentes opciones de personalización de nodos en formato csv
    this.tree = new PhylocanvasGL(
      document.querySelector("#demo"),
      {
        interactive:false,
        showLabels: true,
        showLeafLabels: true,
        size: screenSize,
        alignLabels: true,
        nodeSize:16,
        source: "(((((((Rosaceae,(Elaeagnaceae,(Rhamnaceae,Ulmaceae,(Cannabaceae,(Urticaceae,Moraceae))))),(((Begoniaceae,Datiscaceae),Cucurbitaceae),(Fagaceae,((Betulaceae,Casuarinaceae),Juglandaceae,Myricaceae)))),(Fabaceae,Quillajaceae)),(Celastraceae,((Elaeocarpaceae,Cephalotaceae,(Oxalidaceae,Connaraceae)),(((Tumeraceae,Passifloraceae),Violaceae),((Calophyliaceae,Myricaceae),Clusiaceae),(Rhizophoraceae,Erythroxylaceae),Salicaceae,Chrysobalanaceae,Malphighiaceae,Euphorbiaceae,Linaceae,Caryocaraceae,Rafflesiaceae)))),((((((Rutaceae,Meliaceae),Sapindaceae,(Anacardiaceae,Burseraceae)),(Malvaceae,Cochlospermaceae,Thymelaceae,(Dipterocarpaceae,Cistaceae))),((Resedaceae,(Cleomaceae,Brassicaceae)),((Caricaceae,Moringaceae),(Tropaeolaceae,Akaniaceae)))),Staphyleaceae),(((Myrtaceae,Melastomataceae),(Onagraceae,Lythraceae)),Geraniaceae))),Vitaceae),((Cornaceae,Nyssaceae,Hydrangeaceae),(Balsaminaceae,(Polemoniaceae,(Lecythidaceae,Theaceae,Sapotaceae,Ebenaceae,(Myrsinaceae,Primulaceae),(Ericaceae,(Actinidiaceae,Sarraceniaceae))))),(((Icacinaceae,Eucommiaceae),((Solanaceae,Convolvulaceae),Boraginaceae,(Oleaceae,(Gesneriaceae,Lentibulariaceae,Plantaginaceae,Bignoniaceae,Acanthaceae,Orobanchaceae,Pedaliaceae,Lamiaceae,Phrymaceae,Scrophulariaceae,Linderniaceae,Paulowniaceae)),(Rubiaceae,(Apocynaceae,Loganiaceae,Gentianaceae)))),(Caprifoliaceae,(Apiaceae,Araliaceae),(Aquifoliaceae,(Campanulaceae,(Argophyllaceae,(Menyanthaceae,(Goodeniaceae,Asteraceae)))))))),((((Caryophyllaceae,AmaranthaceaeChenopodiaceae),((Microteaceae,Nyctaginaceae),(Kewaceae,Cactaceae,(Limeacea,Molluginaceae)))),(Simmondsiaceae,Macarthuriaceae)),((Plumbaginaceae,Polygonaceae),Droseraceae)),(Hamamelidaceae,(Paeoniaceae,(Crassulaceae,Saxifragaceae))),(Olacaceae,Santalaceae));",
        type: TreeTypes.Rectangular,
        styles: (
          metadata
            .split("\n")
            .map((line) => line.split(","))
            .reduce(
              (styles, [id, fillColour]) => { 
                styles[id] = { fillColour };
                return styles;
              },
              {}
            )
        ),
      },
    );

  }
  //Renderiza el arbol y lo hace interactivo
  ngOnInit(): void {
    this.renderizeFilogeneticTree();
    this.setInteractive();
  }

  /*Cuando se hace click en un nodo o su nombre te lleva a la vista de esa familia, en caso de AmaranthaceaeChenopodiaceae,
  abre un cuadro de dialogo para elegir cual se quiere ver*/
  
  goToFamily(): void {
    var param = this.tree['props']['selectedIds']
    if(param!==undefined){
      if(param=="AmaranthaceaeChenopodiaceae"){
        this.openDialog()
      }else{
    this.router.navigate(['family/' + param]);
      }
    }
  }
  //Hace el árbol interactivo
  setInteractive():void{
    this.tree.setProps({
      interactive: true
    });
  }
 
  //Abre el cuadro de dialogo
  openDialog(): void {
    const dialogRef = this.dialog.open(DialogComponent, {
      width: '450px',
      data: {}
    });
}

}
